#-*- coding: utf-8 -*-
import unittest
from base import EEADesign2006TestCase


class TestMailTranslation(EEADesign2006TestCase):

    def sendMail(self):
        me = 'user@example.com'
        you = 'admin@megacorp.com'
        subj = 'Test'
        variables = {
            'sender_from_address' : me,
            'sender_fullname'     : 'Test Testsson',
            'url'                 : 'eea.europa.eu',
            'subject'             : subj,
            'message'             : 'Hej värld',
        }
        plone_id = self.portal.getId()
        view = self.portal.restrictedTraverse('@@mail_translation_service')
        view(plone_id, variables, you, me, subject=subj, subtype='plain', charset='utf-8', debug=True, From=me)
        view.mail.join()
        return view.mail.result.message.get_payload(decode=True)

    def testSwedishToEnglish(self):
        self.portal.REQUEST['LANGUAGE'] = 'sv'
        output = self.sendMail()
        output = [i.strip() for i in output.split('\n') if i != '']
        translation = output[8]
        self.assertEquals(translation != 'Hej värld', True)
        self.assertEquals(len(translation.split(' ')), 2)

    def testNoTranslationAvailable(self):
        self.portal.REQUEST['LANGUAGE'] = 'foobar'
        output = self.sendMail()
        expected = 'No translation available for language foobar'
        self.failUnless(expected in output)

    def testOriginalLanguageIsEnglish(self):
        self.portal.REQUEST['LANGUAGE'] = 'en'
        output = self.sendMail()
        expected = 'Original language is english, so no translation required'
        self.failUnless(expected in output)


def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestMailTranslation))
    return suite
